==> Ethna-2.3.2.tgz: Ethna-2.3.2/skel/skel.action_test.php <==
<?php
/**
 *  {$action_path}
 *
 *  @author     {$author}
 *  @package    {$project_id}
 *  @version    $Id: skel.action_test.php 209 2006-03-23 13:16:37Z fujimoto $
 */

/**
 *  {$action_name}եΥƥȥ
 *
 *  @author     {$author}
 *  @access     public
 *  @package    {$project_id}
 */
class {$action_form}_TestCase extends Ethna_UnitTestCase
{
    /**
     *  @access private
     *  @var    string  ̾
     */
    var $action_name = '{$action_name}';

    /**
     *    ƥȤν
     *
     *    @access public
     */
    function setUp()
    {
        $this->createActionForm();  // եκ
    }

    /**
     *    ƥȤθ
     *
     *    @access public
     */
    function tearDown()
    {
    }

    /**
     *  {$action_name}եΥץƥȥ
     *
     *  @access public
     */
    /*
    function test_formSample()
    {
        // ե
        $this->af->set('id', 1);

        // {$action_name}ե͸
        $this->assertEqual($this->af->validate(), 0);
    }
    */
}

/**
 *  {$action_name}Υƥȥ
 *
 *  @author     {$author}
 *  @access     public
 *  @package    {$project_id}
 */
class {$action_class}_TestCase extends Ethna_UnitTestCase
{
    /**
     *  @access private
     *  @var    string  ̾
     */
    var $action_name = '{$action_name}';

    /**
     *    ƥȤν
     *
     *    @access public
     */
    function setUp()
    {
        $this->createActionForm();  // եκ
        $this->createActionClass(); // 󥯥饹κ

        $this->session->start();            // åγ
    }

    /**
     *    ƥȤθ
     *
     *    @access public
     */
    function tearDown()
    {
        $this->session->destroy();      // å˴
    }

    /**
     *  {$action_name}󥯥饹Υץƥȥ
     *
     *  @access public
     */
    /*
    function test_actionSample()
    {
        // ե
        $this->af->set('id', 1);

        // {$action_name}¹ǧڽ
        $forward_name = $this->ac->authenticate();
        $this->assertNull($forward_name);

        // {$action_name}
        $forward_name = $this->ac->prepare();
        $this->assertNull($forward_name);

        // {$action_name}μ
        $forward_name = $this->ac->perform();
        $this->assertEqual($forward_name, '{$action_name}');
    }
    */
}
?>

==> Ethna-2.3.7.tgz: Ethna-2.3.7/skel/skel.action_test.php <==
<?php
/**
 *  {$action_path}
 *
 *  @author     {$author}
 *  @package    {$project_id}
 *  @version    $Id: skel.action_test.php 503 2008-04-25 04:06:08Z mumumu-org $
 */

/**
 *  {$action_name}եΥƥȥ
 *
 *  @author     {$author}
 *  @access     public
 *  @package    {$project_id}
 */
class {$action_form}_TestCase extends Ethna_UnitTestCase
{
    /**
     *  @access private
     *  @var    string  ̾
     */
    var $action_name = '{$action_name}';

    /**
     *    ƥȤν
     *
     *    @access public
     */
    function setUp()
    {
        $this->createActionForm();  // եκ
    }

    /**
     *    ƥȤθ
     *
     *    @access public
     */
    function tearDown()
    {
    }

    /**
     *  {$action_name}եΥץƥȥ
     *
     *  @access public
     */
    function test_formSample()
    {
        /*
        // ե
        $this->af->set('id', 1);

        // {$action_name}ե͸
        $this->assertEqual($this->af->validate(), 0);
        */

        /**
         *  TODO: ƥȥ򵭽ҤƲ
         *  @see http://simpletest.org/en/first_test_tutorial.html
         *  @see http://simpletest.org/en/unit_test_documentation.html
         */
        $this->fail('No Test! write Test!');
    }
}

/**
 *  {$action_name}Υƥȥ
 *
 *  @author     {$author}
 *  @access     public
 *  @package    {$project_id}
 */
class {$action_class}_TestCase extends Ethna_UnitTestCase
{
    /**
     *  @access private
     *  @var    string  ̾
     */
    var $action_name = '{$action_name}';

    /**
     *    ƥȤν
     *
     *    @access public
     */
    function setUp()
    {
        $this->createActionForm();  // եκ
        $this->createActionClass(); // 󥯥饹κ

        $this->session->start();            // åγ
    }

    /**
     *    ƥȤθ
     *
     *    @access public
     */
    function tearDown()
    {
        $this->session->destroy();      // å˴
    }

    /**
     *  {$action_name}󥯥饹Υץƥȥ
     *
     *  @access public
     */
    function test_actionSample()
    {
        /*
        // ե
        $this->af->set('id', 1);

        // {$action_name}¹ǧڽ
        $forward_name = $this->ac->authenticate();
        $this->assertNull($forward_name);

        // {$action_name}
        $forward_name = $this->ac->prepare();
        $this->assertNull($forward_name);

        // {$action_name}μ
        $forward_name = $this->ac->perform();
        $this->assertEqual($forward_name, '{$action_name}');
        */

        /**
         *  TODO: ƥȥ򵭽ҤƲ
         *  @see http://simpletest.org/en/first_test_tutorial.html
         *  @see http://simpletest.org/en/unit_test_documentation.html
         */
        $this->fail('No Test! write Test!');
    }
}
?>
